@@ -41,21 +41,20 @@ class Testproject(unittest.TestCase):
         project_root = find_project_root(__file__)
         cls._context = Context(name="DEFAULT")
 
-        cls._connection = Connection(server='http://localhost:7200',
-                                     repo="oldap",
-                                     userId="rosenth",
+        cls._connection = Connection(userId="rosenth",
                                      credentials="RioGrande",
                                      context_name="DEFAULT")
-        cls._unpriv = Connection(server='http://localhost:7200',
-                                 repo="oldap",
-                                 userId="fornaro",
+        cls._unpriv = Connection(userId="fornaro",
                                  credentials="RioGrande",
                                  context_name="DEFAULT")
 
 
         cls._connection.clear_graph(Xsd_QName('oldap:admin'))
+
         file = project_root / 'oldaplib' / 'ontologies' / 'admin.trig'
         cls._connection.upload_turtle(file)
+        file = project_root / 'oldaplib' / 'ontologies' / 'admin-testing.trig'
+        cls._connection.upload_turtle(file)
         sleep(1)  # upload may take a while...
 
     @classmethod
